@@ -1226,11 +1226,12 @@ void CXBMCRenderManager::DiscardBuffer()
   m_presentevent.notifyAll();
 }
 
-bool CXBMCRenderManager::GetStats(double &sleeptime, double &pts, int &bufferLevel)
+bool CXBMCRenderManager::GetStats(double &sleeptime, double &pts, int &queued, int &discard)
 {
   CSingleLock lock(m_presentlock);
   sleeptime = m_sleeptime;
   pts = m_presentpts;
-  bufferLevel = m_queued.size() + m_discard.size();
+  queued = m_queued.size();
+  discard  = m_discard.size();
   return true;
 }
