@@ -967,7 +967,23 @@ udf25::udf25( )
 udf25::~udf25( )
 {
   delete m_fp;
-  free(m_udfcache);
+
+  struct udf_cache * cache = (struct udf_cache *) m_udfcache;
+
+  if (!cache)
+    return;
+
+  if (cache->lbs)
+  {
+    for (int n = 0; n < cache->lb_num; n++)
+    {
+      free(cache->lbs[n].data_base);
+    }
+    free(cache->lbs);
+  }
+
+  free(cache->maps);
+  free(cache);
 }
 
 UDF_FILE udf25::UDFFindFile( const char* filename, uint64_t *filesize )
